@@ -185,15 +185,20 @@ D[i,c]=sum((X[i,]-H[c,])^2)
 }
 for (i in 1:n)
 {
+if (min(D[i,])==0)
+{
+U[i,]=rep(0,k)
+U[i,which.min(D[i,])]=1
+}
+else
+{ 
 for (c in 1:k)
 {
-if (D[i,c]==0)
-U[i,c]=1
-else
 U[i,c]=((1/D[i,c])^(1/(m-1)))/sum(((1/D[i,])^(1/(m-1))))
 }
 }
 }
+}
 })
 func=sum((U^m)*D)
 cput[rs]=cputime[1]
@@ -231,6 +236,7 @@ out$iter=it
 out$k=k
 out$m=m
 out$ent=NULL
+out$b=NULL
 out$vp=NULL
 out$delta=NULL
 out$stand=stand
